@@ -26,7 +26,7 @@ add_dummy <- function(
     start.model, 
     x, 
     data = eval(start.model$call$data),
-    mc.cores = getOption('mc.cores'), 
+    mc.cores = getOption('cores'), 
     ...
 ) {
   
